@@ -709,7 +709,13 @@ cache_one_item (const char *uri,
     NautilusDragSelectionItem *item;
 
     item = nautilus_drag_selection_item_new ();
-    item->uri = g_strdup (uri);
+    item->uri = nautilus_uri_to_native_uri (uri);
+
+    if (item->uri == NULL)
+    {
+        item->uri = g_strdup (uri);
+    }
+
     item->file = nautilus_file_get_by_uri (uri);
     item->icon_x = x;
     item->icon_y = y;
