@@ -167,9 +167,11 @@ struct _NautilusFilesViewClass {
          * return whether the view is at minimum size (furthest-out zoom level) */
         gboolean (* can_zoom_out)            (NautilusFilesView *view);
 
-        /* The current zoom level as a percentage of the default (0, 1] */
+        /* The current zoom level as a percentage of the default. */
         gfloat   (* get_zoom_level_percentage) (NautilusFilesView *view);
 
+        gboolean (*is_zoom_level_default)      (NautilusFilesView *view);
+
         /* reveal_selection is a function pointer that subclasses may
          * override to make sure the selected items are sufficiently
          * apparent to the user (e.g., scrolled into view). By default,
@@ -265,6 +267,9 @@ void                nautilus_files_view_activate_files                   (Nautil
                                                                           GList                   *files,
                                                                           NautilusWindowOpenFlags  flags,
                                                                           gboolean                 confirm_multiple);
+void                nautilus_files_view_activate_file                    (NautilusFilesView       *view,
+                                                                          NautilusFile            *file,
+                                                                          NautilusWindowOpenFlags  flags);
 void                nautilus_files_view_preview_files                    (NautilusFilesView *view,
                                                                           GList             *files,
                                                                           GArray            *locations);
