@@ -1,4 +1,3 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 
 /* nautilus-mime-actions.h - uri-specific versions of mime action functions
 
@@ -27,7 +26,7 @@
 #include <gio/gio.h>
 #include <glib/gi18n.h>
 
-#include <libnautilus-private/nautilus-file.h>
+#include "nautilus-file.h"
 
 #include "nautilus-window.h"
 
@@ -38,7 +37,7 @@ GList *                nautilus_mime_get_applications_for_file            (Nauti
 
 GAppInfo *             nautilus_mime_get_default_application_for_files    (GList                   *files);
 
-gboolean               nautilus_mime_file_opens_in_view                   (NautilusFile            *file);
+gboolean               nautilus_mime_file_extracts                        (NautilusFile            *file);
 gboolean               nautilus_mime_file_opens_in_external_app           (NautilusFile            *file);
 gboolean               nautilus_mime_file_launches                        (NautilusFile            *file);
 void                   nautilus_mime_activate_files                       (GtkWindow               *parent_window,
