@@ -37,12 +37,14 @@ void                nautilus_search_hit_set_modification_time (NautilusSearchHit
 							       GDateTime         *date);
 void                nautilus_search_hit_set_access_time       (NautilusSearchHit *hit,
 							       GDateTime         *date);
-
+void                nautilus_search_hit_set_fts_snippet       (NautilusSearchHit *hit,
+                                                               const gchar       *snippet);
 void                nautilus_search_hit_compute_scores        (NautilusSearchHit *hit,
 							       NautilusQuery     *query);
 
 const char *        nautilus_search_hit_get_uri               (NautilusSearchHit *hit);
 gdouble             nautilus_search_hit_get_relevance         (NautilusSearchHit *hit);
+const gchar *       nautilus_search_hit_get_fts_snippet       (NautilusSearchHit *hit);
 
 G_END_DECLS
 
