@@ -566,14 +566,14 @@ result_list_attributes_ready_cb (GList    *file_list,
     GFile *file_location;
     GList *l;
     gchar *uri, *display_name;
-    gchar *description;
+    gchar *path, *description;
     gchar *thumbnail_path;
     GIcon *gicon;
     GFile *location;
     GVariant *meta_variant;
     gint icon_scale;
 
-    icon_scale = gdk_screen_get_monitor_scale_factor (gdk_screen_get_default (), 0);
+    icon_scale = gdk_monitor_get_scale_factor (gdk_display_get_monitor (gdk_display_get_default (), 0));
 
     for (l = file_list; l != NULL; l = l->next)
     {
@@ -583,7 +583,8 @@ result_list_attributes_ready_cb (GList    *file_list,
         uri = nautilus_file_get_uri (file);
         display_name = get_display_name (data->self, file);
         file_location = nautilus_file_get_location (file);
-        description = g_file_get_path (file_location);
+        path = g_file_get_path (file_location);
+        description = path ? g_path_get_dirname (path) : NULL;
 
         g_variant_builder_add (&meta, "{sv}",
                                "id", g_variant_new_string (uri));
@@ -625,6 +626,7 @@ result_list_attributes_ready_cb (GList    *file_list,
                              g_strdup (uri), g_variant_ref_sink (meta_variant));
 
         g_free (display_name);
+        g_free (path);
         g_free (description);
         g_free (uri);
     }
