@@ -189,80 +189,6 @@ nautilus_pop_up_context_menu (GtkWidget      *parent,
     g_object_unref (gtk_menu);
 }
 
-char *
-nautilus_escape_action_name (const char *action_name,
-                             const char *prefix)
-{
-    GString *s;
-
-    if (action_name == NULL)
-    {
-        return NULL;
-    }
-
-    s = g_string_new (prefix);
-
-    while (*action_name != 0)
-    {
-        switch (*action_name)
-        {
-            case '\\':
-            {
-                g_string_append (s, "\\\\");
-            }
-            break;
-
-            case '/':
-            {
-                g_string_append (s, "\\s");
-            }
-            break;
-
-            case '&':
-            {
-                g_string_append (s, "\\a");
-            }
-            break;
-
-            case '"':
-            {
-                g_string_append (s, "\\q");
-            }
-            break;
-
-            case ' ':
-            {
-                g_string_append (s, "+");
-            }
-            break;
-
-            case '(':
-            {
-                g_string_append (s, "#");
-            }
-            break;
-
-            case ')':
-            {
-                g_string_append (s, "^");
-            }
-            break;
-
-            case ':':
-            {
-                g_string_append (s, "\\\\");
-            }
-            break;
-
-            default:
-                g_string_append_c (s, *action_name);
-        }
-
-        action_name++;
-    }
-    return g_string_free (s, FALSE);
-}
-
 #define NAUTILUS_THUMBNAIL_FRAME_LEFT 3
 #define NAUTILUS_THUMBNAIL_FRAME_TOP 3
 #define NAUTILUS_THUMBNAIL_FRAME_RIGHT 3
