@@ -46,9 +46,6 @@
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#ifdef HAVE_X11_XF86KEYSYM_H
-#include <X11/XF86keysym.h>
-#endif
 #include "nautilus-dnd.h"
 #include "nautilus-file-utilities.h"
 #include "nautilus-file-attributes.h"
@@ -171,21 +168,19 @@ static const struct
     const char *action;
 } extra_window_keybindings [] =
 {
-#ifdef HAVE_X11_XF86KEYSYM_H
     /* Window actions */
-    { XF86XK_AddFavorite, "bookmark-current-location" },
-    { XF86XK_Favorites, "bookmarks" },
-    { XF86XK_Go, "enter-location" },
-    { XF86XK_HomePage, "go-home" },
-    { XF86XK_OpenURL, "enter-location" },
-    { XF86XK_Refresh, "reload" },
-    { XF86XK_Reload, "reload" },
-    { XF86XK_Search, "search" },
-    { XF86XK_Start, "go-home" },
-    { XF86XK_Stop, "stop" },
-    { XF86XK_Back, "back" },
-    { XF86XK_Forward, "forward" },
-#endif
+    { GDK_KEY_AddFavorite, "bookmark-current-location" },
+    { GDK_KEY_Favorites, "bookmarks" },
+    { GDK_KEY_Go, "enter-location" },
+    { GDK_KEY_HomePage, "go-home" },
+    { GDK_KEY_OpenURL, "enter-location" },
+    { GDK_KEY_Refresh, "reload" },
+    { GDK_KEY_Reload, "reload" },
+    { GDK_KEY_Search, "search" },
+    { GDK_KEY_Start, "go-home" },
+    { GDK_KEY_Stop, "stop" },
+    { GDK_KEY_Back, "back" },
+    { GDK_KEY_Forward, "forward" },
 };
 
 static const GtkPadActionEntry pad_actions[] = {
@@ -674,33 +669,6 @@ nautilus_window_open_location_full (NautilusWindow          *window,
     g_object_unref (location);
 }
 
-static int
-bookmark_list_get_uri_index (GList *list,
-                             GFile *location)
-{
-    NautilusBookmark *bookmark;
-    GList *l;
-    GFile *tmp;
-    int i;
-
-    g_return_val_if_fail (location != NULL, -1);
-
-    for (i = 0, l = list; l != NULL; i++, l = l->next)
-    {
-        bookmark = NAUTILUS_BOOKMARK (l->data);
-
-        tmp = nautilus_bookmark_get_location (bookmark);
-        if (g_file_equal (location, tmp))
-        {
-            g_object_unref (tmp);
-            return i;
-        }
-        g_object_unref (tmp);
-    }
-
-    return -1;
-}
-
 static void
 unset_focus_widget (NautilusWindow *window)
 {
@@ -1964,22 +1932,7 @@ path_bar_location_changed_callback (GtkWidget      *widget,
                                     GFile          *location,
                                     NautilusWindow *window)
 {
-    NautilusWindowPrivate *priv;
-    NautilusWindowSlot *slot;
-    int i;
-
-    priv = nautilus_window_get_instance_private (window);
-    slot = priv->active_slot;
-    /* check whether we already visited the target location */
-    i = bookmark_list_get_uri_index (nautilus_window_slot_get_back_history (slot), location);
-    if (i >= 0)
-    {
-        nautilus_window_back_or_forward (window, TRUE, i, 0);
-    }
-    else
-    {
-        nautilus_window_open_location_full (window, location, 0, NULL, NULL);
-    }
+    nautilus_window_open_location_full (window, location, 0, NULL, NULL);
 }
 
 static void
@@ -2944,6 +2897,7 @@ real_window_close (NautilusWindow *window)
     g_return_if_fail (NAUTILUS_IS_WINDOW (window));
 
     nautilus_window_save_geometry (window);
+    nautilus_window_set_active_slot (window, NULL);
 
     gtk_widget_destroy (GTK_WIDGET (window));
 }
